@@ -15,7 +15,9 @@
 					var data = {
 						oid: oid
 					}
-					$.ZTFY.ajax.post(window.location.href + '/@@ajax/ajaxRemove', data, window.location.reload, function(request, status, error) {
+					$.ZTFY.ajax.post(window.location.href + '/@@ajax/ajaxRemove', data, function() {
+						window.location.reload();
+					}, function(request, status, error) {
 						jAlert(request.responseText, $.ZTFY.I18n.ERROR_OCCURED, window.location.reload);
 					});
 				}
@@ -158,6 +160,20 @@
 				$.ZTFY.dialog.open('++terms++/' + term + '/@@properties.html');
 			},
 
+			// Open term properties from search engine
+			openTermFromSearch: function(source) {
+				if (source instanceof $.Event) {
+					var source  = source.srcElement || source.target;
+				}
+				var term = $(source).text().replace(/ /g, '%20');
+				if (term) {
+					if ($.browser.msie) {
+						term = $.UTF8.encode(term);
+					}
+					$.ZTFY.dialog.open('++terms++/' + term + '/@@properties.html');
+				}
+			},
+
 			// Open term extension properties dialog
 			openExtension: function(source) {
 				var view = $(source).data('ztfy-view').replace('/ /g', '%20');
@@ -178,6 +194,10 @@
 
 			// Switch extract selection for a given term
 			switchExtract: function(source) {
+				if (source instanceof $.Event) {
+					$.ZTFY.skin.stopEvent(source);
+					var source  = source.srcElement || source.target;
+				}
 				var extract = $(source).data('ztfy-extract-name');
 				var checker = $('DIV.extract SPAN.showhide[data-ztfy-extract-name="' + extract + '"]');
 				if (checker.data('ztfy-enabled') == false) {
@@ -259,6 +279,30 @@
 			return result;
 		},
 
+		// Thesaurus terms search engine entry point
+		findTermsWithLabel: function(query, thesaurus_name, extract_name) {
+			var result;
+			var options = {
+				url: $.ZTFY.ajax.getAddr(),
+				type: 'POST',
+				method: 'findTermsWithLabel',
+				async: false,
+				params: {
+					query: query,
+					thesaurus_name: thesaurus_name || '',
+					extract_name: extract_name || ''
+				},
+				success: function(data, status) {
+					result = data.result;
+				},
+				error: function(request, status, error) {
+					jAlert(request.responseText, "Error !", window.location.reload);
+				}
+			}
+			$.jsonRpc(options);
+			return result;
+		},
+
 		// Thesaurus download management
 		download: function(form) {
 			$.ZTFY.form.check(function() {
@@ -276,6 +320,8 @@
 			$(form).attr('action', target)
 				   .attr('target', 'downloadFrame')
 				   .ajaxSubmit({
+					   iframe: true,
+					   iframeTarget: iframe,
 					   success: function() {
 							$.ZTFY.dialog.close();
 					   }
@@ -291,7 +337,7 @@
 	 */
 	$.ZTFY.thesaurus.I18n = {
 
-		CONFIRM_UNSELECT_WITH_CHILD: "Removing this term from this extract will also remove all it's specific terms. Are you sure?"
+		CONFIRM_UNSELECT_WITH_CHILD: "Removing this term from this extract will also remove all it's specific terms and their synonyms. Are you sure?"
 
 	}
 
@@ -305,7 +351,8 @@
 	 */
 	$(document).ready(function() {
 		$('DIV.extract').on('click', 'SPAN.showhide', $.ZTFY.thesaurus.tree.showHideExtract);
-		$('DIV.tree').on('click', 'SPAN.square', $.ZTFY.thesaurus.tree.switchExtract);
+		$('DIV.tree SPAN.square').click($.ZTFY.thesaurus.tree.switchExtract);
+		$('FIELDSET.search').on('click', 'A.bit-box', $.ZTFY.thesaurus.tree.openTermFromSearch);
 	});
 
 })(jQuery);
\ No newline at end of file
