@@ -44,8 +44,8 @@ class ThesaurusTermAddForm(DialogAddForm):
     """Thesaurus term add form"""
 
     fields = field.Fields(IThesaurusTermInfo).select('label', 'alt', 'definition', 'note',
-                                                     'generic', 'associations', 'usage', 'used_for',
-                                                     'extensions', 'status', 'created', 'modified')
+                                                     'generic', 'associations', 'usage',
+                                                     'extensions', 'status', 'created')
 
     legend = _("Add new term")
 
@@ -114,45 +114,72 @@ class ThesaurusTermEditForm(DialogEditForm):
     def updateWidgets(self):
         super(ThesaurusTermEditForm, self).updateWidgets()
         self.widgets['specifics'].mode = DISPLAY_MODE
+        self.widgets['used_for'].mode = DISPLAY_MODE
         self.widgets['extracts'].mode = DISPLAY_MODE
+        self.widgets['created'].mode = DISPLAY_MODE
 
     def applyChanges(self, data):
         term = self.getContent()
         thesaurus = getParent(term, IThesaurus)
         old_generic = term.generic
+        old_usage = term.usage
         changes = super(ThesaurusTermEditForm, self).applyChanges(data)
         # Move term if label changed
         if 'label' in changes.get(IThesaurusTermInfo, []):
             IObjectMover(self.context).moveTo(traversing_api.getParent(term), term.label)
-        # Check terms and thesaurus top terms if generic changed
+        # Check terms and thesaurus top terms if generic or usage changed
         self._v_generic_changed = old_generic != term.generic
+        self._v_usage_changed = old_usage != term.usage
         if self._v_generic_changed:
             # Check previous value
             if old_generic is not None:
-                # add a previous generic ?
+                # add a previous generic?
                 # remove term from list of previous generic's specifics
                 specifics = removeSecurityProxy(old_generic.specifics)
                 if term in specifics:
                     specifics.remove(term)
                     old_generic.specifics = specifics
             else:
-                # didn't have a generic ?
+                # didn't have a generic?
                 # may remove term from thesaurus top terms
-                if term in thesaurus.top_terms:
-                    top_terms = removeSecurityProxy(thesaurus.top_terms)
+                top_terms = removeSecurityProxy(thesaurus.top_terms)
+                if term in top_terms:
                     top_terms.remove(term)
                     thesaurus.top_terms = top_terms
             # Check new value
             if term.generic is None:
-                # no generic ?
+                # no generic and not a synonym?
                 # term should be added to thesaurus top terms
-                if term not in thesaurus.top_terms:
+                if (term.usage is None) and (term not in thesaurus.top_terms):
                     thesaurus.top_terms = thesaurus.top_terms + [term, ]
             else:
                 # new generic ?
                 # add term to generic's specific terms
                 if term not in term.generic.specifics:
                     term.generic.specifics = term.generic.specifics + [term, ]
+        if self._v_usage_changed:
+            # Check previous value
+            if old_usage is not None:
+                # add a previous usage term?
+                used_for = removeSecurityProxy(old_usage.used_for)
+                if term in used_for:
+                    used_for.remove(term)
+                    old_usage.used_for = used_for
+            # Check new term usage
+            if term.usage is None:
+                # no usage? Maybe a top term...
+                if (term.generic is None) and (term not in thesaurus.top_terms):
+                    thesaurus.top_terms = thesaurus.top_terms + [term, ]
+            else:
+                # term usage?
+                # remove term from top-terms...
+                top_terms = removeSecurityProxy(thesaurus.top_terms)
+                if term in top_terms:
+                    top_terms.remove(term)
+                    thesaurus.top_terms = top_terms
+                # add term to usage's synonyms
+                if term not in term.usage.used_for:
+                    term.usage.used_for = term.usage.used_for + [term, ]
         return changes
 
     def getOutput(self, writer, parent, changes=()):
