@@ -19,6 +19,7 @@ from datetime import datetime
 from persistent import Persistent
 
 # import Zope3 interfaces
+from zope.dublincore.interfaces import IZopeDublinCore
 
 # import local interfaces
 from ztfy.thesaurus.interfaces.extension import IThesaurusTermExtension
@@ -101,8 +102,6 @@ class ThesaurusTerm(Persistent, Contained):
         self._generic = generic = removeSecurityProxy(value)
         if (generic is not None) and generic.extracts:
             self.extracts = (self.extracts or set()) & generic.extracts
-        else:
-            self.extracts = set()
 
     @property
     def specifics(self):
@@ -152,6 +151,9 @@ class ThesaurusTerm(Persistent, Contained):
                 for term in self.specifics:
                     term.extracts = (term.extracts or set()) - removed
             self._extracts = removeSecurityProxy(new_value)
+            # Extracts selection also applies to term synonyms...
+            for term in self.used_for or ():
+                term.extracts = self.extracts
 
     def addExtract(self, extract, check=True):
         if IThesaurusExtractInfo.providedBy(extract):
@@ -204,7 +206,11 @@ class ThesaurusTerm(Persistent, Contained):
 
     @property
     def created(self):
-        return self._created
+        if self._created is not None:
+            return self._created
+        dc = IZopeDublinCore(self, None)
+        if dc is not None:
+            return tztime(dc.created)
 
     @created.setter
     def created(self, value):
@@ -217,7 +223,11 @@ class ThesaurusTerm(Persistent, Contained):
 
     @property
     def modified(self):
-        return self._modified
+        if self._modified is not None:
+            return self._modified
+        dc = IZopeDublinCore(self, None)
+        if dc is not None:
+            return tztime(dc.modified)
 
     @modified.setter
     def modified(self, value):
