@@ -154,13 +154,19 @@ class Thesaurus(Persistent, Contained):
 
     @property
     def title(self):
-        return IZopeDublinCore(self).title
+        dc = IZopeDublinCore(self, None)
+        if dc is not None:
+            return dc.title
+        else:
+            return self._title
 
     @title.setter
     def title(self, value):
         if value != self._title:
             self._title = value
-            IZopeDublinCore(self).title = value
+            dc = IZopeDublinCore(self, None)
+            if dc is not None:
+                dc.title = value
 
     def sublocations(self):
         return (self.terms, self.catalog)
@@ -171,7 +177,8 @@ class Thesaurus(Persistent, Contained):
 
     @top_terms.setter
     def top_terms(self, value):
-        self._top_terms = [removeSecurityProxy(term) for term in value or ()]
+        self._top_terms = [ removeSecurityProxy(term) for term in value or ()
+                                                               if term.usage is None ]
 
     def initCatalog(self):
         catalog = self.catalog = Catalog()
